 lib/crypto/c_src/crypto_drv.c |   23 +++++++++++++++++++++++
 lib/crypto/doc/src/crypto.xml |   20 ++++++++++++++++++++
 lib/crypto/src/crypto.erl     |    9 +++++++++
 3 files changed, 52 insertions(+), 0 deletions(-)

diff --git a/lib/crypto/c_src/crypto_drv.c b/lib/crypto/c_src/crypto_drv.c
index a5b301f..736da1a 100644
--- a/lib/crypto/c_src/crypto_drv.c
+++ b/lib/crypto/c_src/crypto_drv.c
@@ -212,6 +212,8 @@ static ErlDrvEntry crypto_driver_entry = {
 
 #define DRV_BF_CFB64_ENCRYPT     59
 #define DRV_BF_CFB64_DECRYPT     60
+#define DRV_BF_ECB_ENCRYPT       61
+#define DRV_BF_ECB_DECRYPT       62
 
 /* #define DRV_CBC_IDEA_ENCRYPT    34 */
 /* #define DRV_CBC_IDEA_DECRYPT    35 */
@@ -534,6 +536,27 @@ static int control(ErlDrvData drv_data, unsigned int command, char *buf,
 	return dlen;
     }
 
+    case DRV_BF_ECB_ENCRYPT:
+    case DRV_BF_ECB_DECRYPT:
+    {
+	/* buf = klen[4] key data */
+	int bf_direction;
+	const unsigned char *bf_dbuf; /* blowfish input data */
+	BF_KEY bf_key; /* blowfish key 8 */
+
+	klen = get_int32(buf);
+	key = buf + 4;
+	bf_dbuf = key + klen;
+	dlen = len - 4 - klen;
+	if (dlen < 0) return -1;
+	BF_set_key(&bf_key, klen, key);
+	bin = return_binary(rbuf,rlen,dlen);
+	if (bin==NULL) return -1;
+	bf_direction = command == DRV_BF_ECB_ENCRYPT ? BF_ENCRYPT : BF_DECRYPT;
+	BF_ecb_encrypt(bf_dbuf, bin, &bf_key, bf_direction);
+	return dlen;
+    }
+
 /*     case DRV_CBC_IDEA_ENCRYPT: */
 /*     case DRV_CBC_IDEA_DECRYPT: */
          /* buf = key[16] ivec[8] data */
diff --git a/lib/crypto/doc/src/crypto.xml b/lib/crypto/doc/src/crypto.xml
index 7d96017..cd48dde 100644
--- a/lib/crypto/doc/src/crypto.xml
+++ b/lib/crypto/doc/src/crypto.xml
@@ -338,6 +338,26 @@ Mpint() = <![CDATA[<<ByteLen:32/integer-big, Bytes:ByteLen/binary>>]]>
       </desc>
     </func>
     <func>
+      <name>blowfish_ecb_encrypt(Key, Text) -> Cipher</name>
+      <fsummary>Encrypt the first 64 bits of <c>Text</c> using Blowfish in ECB mode</fsummary>
+      <type>
+        <v>Key = Text = iolist() | binary()</v>
+        <v>IVec = Cipher = binary()</v>
+      </type>
+      <desc>
+        <p>Encrypts the first 64 bits of <c>Text</c> using Blowfish in ECB mode. <c>Key</c> is the Blowfish key. The length of <c>Text</c> must be at least 64 bits (8 bytes).</p>
+      </desc>
+      <name>blowfish_ecb_decrypt(Key, Text) -> Cipher</name>
+      <fsummary>Decrypt the first 64 bits of <c>Text</c> using Blowfish in ECB mode</fsummary>
+      <type>
+        <v>Key = Text = iolist() | binary()</v>
+        <v>IVec = Cipher = binary()</v>
+      </type>
+      <desc>
+        <p>Decrypts the first 64 bits of <c>Text</c> using Blowfish in ECB mode. <c>Key</c> is the Blowfish key. The length of <c>Text</c> must be at least 64 bits (8 bytes).</p>
+      </desc>
+    </func>
+    <func>
       <name>blowfish_cfb64_encrypt(Key, IVec, Text) -> Cipher</name>
       <fsummary>Encrypt <c>Text</c>using Blowfish in CFB mode with 64
         bit feedback</fsummary>
diff --git a/lib/crypto/src/crypto.erl b/lib/crypto/src/crypto.erl
index 5189677..d15e480 100644
--- a/lib/crypto/src/crypto.erl
+++ b/lib/crypto/src/crypto.erl
@@ -30,6 +30,7 @@
 -export([md5_mac/2, md5_mac_96/2, sha_mac/2, sha_mac_96/2]).
 -export([des_cbc_encrypt/3, des_cbc_decrypt/3, des_cbc_ivec/1]).
 -export([des3_cbc_encrypt/5, des3_cbc_decrypt/5]).
+-export([blowfish_ecb_encrypt/2,blowfish_ecb_decrypt/2]).
 -export([blowfish_cfb64_encrypt/3,blowfish_cfb64_decrypt/3]).
 -export([des_ede3_cbc_encrypt/5, des_ede3_cbc_decrypt/5]).
 -export([aes_cfb_128_encrypt/3, aes_cfb_128_decrypt/3]).
@@ -115,6 +116,8 @@
 
 -define(BF_CFB64_ENCRYPT, 59).
 -define(BF_CFB64_DECRYPT, 60).
+-define(BF_ECB_ENCRYPT,   61).
+-define(BF_ECB_DECRYPT,   62).
 
 %% -define(IDEA_CBC_ENCRYPT, 34).
 %% -define(IDEA_CBC_DECRYPT, 35).
@@ -303,6 +306,12 @@ des_ede3_cbc_decrypt(Key1, Key2, Key3, IVec, Data) ->
 %%
 %% Blowfish
 %%
+blowfish_ecb_encrypt(Key, Data) when byte_size(Data) >= 8 ->
+    control_bin(?BF_ECB_ENCRYPT, Key, list_to_binary([Data])).
+
+blowfish_ecb_decrypt(Key, Data) when byte_size(Data) >= 8 ->
+    control_bin(?BF_ECB_DECRYPT, Key, list_to_binary([Data])).
+
 blowfish_cfb64_encrypt(Key, IVec, Data) when byte_size(IVec) =:= 8 ->
     control_bin(?BF_CFB64_ENCRYPT, Key, list_to_binary([IVec, Data])).
